"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AwsApiParser = void 0;
const graphql_compose_1 = require("graphql-compose");
const AwsService_1 = require("./AwsService");
const AwsConfigITC_1 = __importDefault(require("./types/AwsConfigITC"));
class AwsApiParser {
    constructor(opts) {
        this.name = opts.name || 'Aws';
        this.awsSDK = opts.awsSDK;
        this._serviceMap = {};
        this.getServicesNames();
    }
    getServicesNames() {
        const serviceNames = Object.keys(this.awsSDK).reduce((res, name) => {
            if (this.awsSDK[name].serviceIdentifier) {
                this._serviceMap[this.awsSDK[name].serviceIdentifier] = name;
                res.push(name);
            }
            return res;
        }, []);
        serviceNames.sort();
        return serviceNames;
    }
    getServiceIdentifier(name) {
        if (this._serviceMap[name])
            return name;
        if (!this.awsSDK[name]) {
            throw new Error(`Service with name '${name}' does not exist. Run AwsApiParser.`);
        }
        return this.awsSDK[name].serviceIdentifier;
    }
    getServiceConfig(name) {
        const cfg = this.awsSDK.apiLoader.services[this.getServiceIdentifier(name)];
        if (!cfg) {
            throw new Error(`Service with name '${name}' does not exist.`);
        }
        const versions = Object.keys(cfg);
        if (versions.length === 1) {
            return cfg[versions[0]];
        }
        versions.sort();
        return cfg[versions[versions.length - 1]];
    }
    getService(name) {
        const config = this.getServiceConfig(name);
        return new AwsService_1.AwsService({
            serviceId: this._serviceMap[name] || name,
            prefix: this.name,
            config,
            awsSDK: this.awsSDK,
        });
    }
    getTypeComposer() {
        if (!this.tc) {
            const fields = this.getServicesNames().reduce((res, name) => {
                res[this.getServiceIdentifier(name)] = this.getService(name).getFieldConfig();
                return res;
            }, {});
            this.tc = graphql_compose_1.schemaComposer.createObjectTC({
                name: this.name,
                fields,
                description: `AWS SDK ${this.awsSDK.VERSION}`,
            });
        }
        return this.tc;
    }
    getType() {
        return this.getTypeComposer().getType();
    }
    getFieldConfig() {
        return {
            type: this.getType(),
            args: {
                config: {
                    type: AwsConfigITC_1.default.getType(),
                    description: 'Will override default configs for aws-sdk.',
                },
            },
            resolve: (source, args) => ({
                awsConfig: Object.assign(Object.assign({}, (source && source.awsConfig)), (args && args.config)),
            }),
            description: this.getTypeComposer().getDescription(),
        };
    }
}
exports.AwsApiParser = AwsApiParser;
//# sourceMappingURL=AwsApiParser.js.map