"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AwsParam = void 0;
const graphql_compose_1 = require("graphql-compose");
class AwsParam {
    static convertInputStructure(param, name, shapes) {
        const fields = {};
        if (param.members) {
            Object.keys(param.members).forEach((fname) => {
                fields[fname] = this.convertParamInput(param.members[fname], `${name}${graphql_compose_1.upperFirst(fname)}`, shapes);
            });
        }
        const typename = `${name}Input`;
        if (graphql_compose_1.schemaComposer.has(typename)) {
            console.warn(`Type ${typename} already exists. It seems that aws-sdk has types with same names. Reusing already existed type for GraphQL schema.`);
            return graphql_compose_1.schemaComposer.get(typename);
        }
        const itc = graphql_compose_1.schemaComposer.createInputTC({
            name: typename,
            fields,
        });
        if (Array.isArray(param.required)) {
            itc.makeRequired(param.required);
        }
        return itc;
    }
    static convertOutputStructure(param, name, shapes) {
        const fields = {};
        if (param.members) {
            Object.keys(param.members).forEach((fname) => {
                fields[fname] = this.convertParamOutput(param.members[fname], `${name}${graphql_compose_1.upperFirst(fname)}`, shapes);
            });
        }
        const tc = graphql_compose_1.schemaComposer.createObjectTC({
            name,
            fields,
        });
        if (Array.isArray(param.required)) {
            tc.makeFieldNonNull(param.required);
        }
        return tc;
    }
    static convertParamInput(param, name, shapes) {
        return this._convertParam(param, name, true, shapes);
    }
    static convertParamOutput(param, name, shapes) {
        return this._convertParam(param, name, false, shapes);
    }
    static _convertParam(param, name, isInput, shapes) {
        if (param.type) {
            switch (param.type) {
                case 'boolean':
                    return 'Boolean';
                case 'string':
                    return 'String';
                case 'integer':
                    return 'Int';
                case 'float':
                    return 'Float';
                case 'timestamp':
                    return 'Date';
                case 'structure': {
                    const tc = isInput
                        ? this.convertInputStructure(param, name, shapes)
                        : this.convertOutputStructure(param, name, shapes);
                    if (Object.keys(tc.getFields()).length === 0) {
                        return 'JSON';
                    }
                    return tc;
                }
                case 'map':
                    return 'JSON';
                case 'list':
                    return [this._convertParam(param.member, name, isInput, shapes)];
                default:
                    return 'JSON';
            }
        }
        if (param.shape) {
            return this.convertShape(param, isInput, shapes);
        }
        return 'String';
    }
    static convertShape(param, isInput, shapes) {
        if (shapes) {
            return isInput ? shapes.getInputShape(param.shape) : shapes.getOutputShape(param.shape);
        }
        return 'JSON';
    }
}
exports.AwsParam = AwsParam;
//# sourceMappingURL=AwsParam.js.map