"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AwsService = void 0;
const graphql_compose_1 = require("graphql-compose");
const AwsServiceMetadata_1 = require("./AwsServiceMetadata");
const AwsServiceOperation_1 = require("./AwsServiceOperation");
const AwsShapes_1 = require("./AwsShapes");
const AwsConfigITC_1 = __importDefault(require("./types/AwsConfigITC"));
class AwsService {
    constructor(opts) {
        this.prefix = opts.prefix;
        this.serviceId = opts.serviceId;
        this.awsSDK = opts.awsSDK;
        this.config = opts.config;
        this.metadata = new AwsServiceMetadata_1.AwsServiceMetadata(this.config.metadata);
        this.shapes = new AwsShapes_1.AwsShapes(this.config.shapes, this.getTypeName());
    }
    getTypeName() {
        return `${this.prefix}${graphql_compose_1.upperFirst(this.serviceId)}`;
    }
    static lowerFirst(name) {
        return name.charAt(0).toLowerCase() + name.slice(1);
    }
    getOperationNames() {
        return Object.keys(this.config.operations);
    }
    getOperation(name) {
        const operConfig = this.config.operations[name];
        if (!operConfig) {
            throw new Error(`Operation with name ${name} does not exist.`);
        }
        return new AwsServiceOperation_1.AwsServiceOperation({
            serviceId: this.serviceId,
            name: AwsService.lowerFirst(name),
            prefix: this.prefix,
            config: operConfig,
            shapes: this.shapes,
            awsSDK: this.awsSDK,
        });
    }
    getTypeComposer() {
        if (!this.tc) {
            const fields = this.getOperationNames().reduce((res, name) => {
                res[AwsService.lowerFirst(name)] = this.getOperation(name).getFieldConfig();
                return res;
            }, {});
            this.tc = graphql_compose_1.schemaComposer.createObjectTC({
                name: this.getTypeName(),
                fields,
                description: this.metadata.getDescription(),
            });
        }
        return this.tc;
    }
    getType() {
        return this.getTypeComposer().getType();
    }
    getFieldConfig() {
        return {
            type: this.getType(),
            args: {
                config: {
                    type: AwsConfigITC_1.default.getType(),
                    description: 'Will override default configs for aws-sdk.',
                },
            },
            resolve: (source, args) => ({
                awsConfig: Object.assign(Object.assign({}, (source && source.awsConfig)), (args && args.config)),
            }),
        };
    }
}
exports.AwsService = AwsService;
//# sourceMappingURL=AwsService.js.map