"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AwsServiceOperation = void 0;
const graphql_compose_1 = require("graphql-compose");
const AwsParam_1 = require("./AwsParam");
const AwsConfigITC_1 = __importDefault(require("./types/AwsConfigITC"));
class AwsServiceOperation {
    constructor(opts) {
        this.prefix = opts.prefix;
        this.name = opts.name;
        this.serviceId = opts.serviceId;
        this.awsSDK = opts.awsSDK;
        this.config = opts.config;
        this.shapes = opts.shapes;
    }
    getTypeName() {
        return `${this.prefix}${graphql_compose_1.upperFirst(this.serviceId)}${graphql_compose_1.upperFirst(this.name)}`;
    }
    getType() {
        if (this.config.output && this.config.output.type === 'structure') {
            const tc = AwsParam_1.AwsParam.convertOutputStructure(this.config.output, `${this.getTypeName()}Output`, this.shapes);
            if (Object.keys(tc.getFields()).length === 0) {
                return graphql_compose_1.GraphQLJSON;
            }
            return tc.getType();
        }
        return graphql_compose_1.GraphQLJSON;
    }
    getArgs() {
        if (!this.args) {
            if (!this.config.input) {
                this.args = {};
            }
            else {
                const itc = AwsParam_1.AwsParam.convertInputStructure(this.config.input, this.getTypeName(), this.shapes);
                let type;
                if (Object.keys(itc.getFields()).length === 0) {
                    type = graphql_compose_1.GraphQLJSON;
                }
                else {
                    const hasRequiredFields = itc.getFieldNames().some((f) => itc.isFieldNonNull(f));
                    type = hasRequiredFields ? itc.getTypeNonNull().getType() : itc.getType();
                }
                this.args = {
                    input: {
                        type,
                    },
                };
            }
            this.args.config = {
                type: AwsConfigITC_1.default.getType(),
            };
        }
        return this.args;
    }
    getResolve() {
        return (source, args) => {
            return new Promise((resolve, reject) => {
                const awsConfig = Object.assign(Object.assign({}, (source && source.awsConfig)), (args && args.config));
                const service = new this.awsSDK[this.serviceId](awsConfig);
                service[this.name](args.input, (err, data) => {
                    if (err) {
                        reject(err);
                    }
                    resolve(data);
                });
            });
        };
    }
    getFieldConfig() {
        return {
            type: this.getType(),
            args: this.getArgs(),
            resolve: this.getResolve(),
        };
    }
}
exports.AwsServiceOperation = AwsServiceOperation;
//# sourceMappingURL=AwsServiceOperation.js.map